@@ -10,7 +10,7 @@
 // Copyright (C) 2011 mod_csp project
 // License : Apache Licence 2.0
 //
-// version : 0.0.4
+// version : 0.01
 //
 // Last modification by kumatiki
 //
@@ -69,6 +69,7 @@ module AP_MODULE_DECLARE_DATA csp_module;
 //		include
 ////////////////////////////////////////////////////////////////////////////////////////////////
 
+
 # 1 "growmem.c" 1
 # 9 "growmem.c"
 typedef struct _growMem {
@@ -511,6 +512,8 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
 "#include <apr_strings.h>\n"
 "#include <signal.h>\n"
 "#include <setjmp.h>\n"
+"#include <ap_regex.h>\n"
+"\n"
 "\n"
 "///////////////////////////////////////////////////////////////////////\n"
 "//define \n"
@@ -519,6 +522,9 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
 "#define GET		__get__\n"
 "#define POST	__post__\n"
 "#define COOKIE	__cookie__\n"
+"#define REQUEST __r__\n"
+"#define POOL __p__\n"
+"\n"
 "#define HEADER_IN	__r__->headers_in\n"
 "#define HEADER_OUT	__r__->headers_out\n"
 "\n"
@@ -534,6 +540,16 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
 "#define stncat(...) apr_pstrcat(__p__,__VA_ARGS__,NULL)\n"
 "#define stndup(a) apr_pstrdup (__p__,a)\n"
 "\n"
+"\n"
+"#define unescape_url(a)		ap_unescape_url(a)\n"
+"#define escape_uri(a)		ap_escape_uri(__p__,a)\n"
+"#define escape_html(a)		ap_escape_html(__p__,a)\n"
+"\n"
+"\n"
+"#define	REGEXOK				0\n"
+"#define	REGEXNG				1\n"
+"#define	REGEXERROR			-1\n"
+"\n"
 "///////////////////////////////////////////////////////////////////////\n"
 "//	typedef\n"
 "///////////////////////////////////////////////////////////////////////\n"
@@ -598,6 +614,61 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
 "\n"
 "\n"
 "///////////////////////////////////////////////////////////////////////\n"
+"//	regex\n"
+"///////////////////////////////////////////////////////////////////////\n"
+"int regex_match(char * str,char * pattern){\n"
+"	int ret=0;\n"
+"	ap_regex_t preg;\n"
+"	ap_regmatch_t regm[AP_MAX_REG_MATCH];\n"
+"	if (0 == ap_regcomp(&preg, pattern, 0)) {\n"
+"		if (0 == ap_regexec(&preg, str, AP_MAX_REG_MATCH, regm, 0)) {\n"
+"			ret = REGEXOK;\n"
+"		} else {\n"
+"			ret = REGEXNG;\n"
+"		}\n"
+"	} else {\n"
+"		ret = REGEXERROR;\n"
+"	}\n"
+"	ap_regfree(&preg);\n"
+"	return ret;\n"
+"}\n"
+"\n"
+"char * regex_replace(char *src, char *pattern, char *replaceStr)\n"
+"{\n"
+"	ap_regmatch_t match[AP_MAX_REG_MATCH];\n"
+"	const char *result=\"\";\n"
+"	int rc = 0;\n"
+"\n"
+"	ap_regex_t _regexp;\n"
+"	ap_regex_t * regexp = &_regexp;\n"
+"\n"
+"	int ans = ap_regcomp(&_regexp, pattern, 0);\n"
+"\n"
+"	if(ans!=0)\n"
+"		return NONE;\n"
+"\n"
+"\n"
+"	int soffset = 0, eoffset = 0;\n"
+"	char *str = NULL;\n"
+"	const char *tail = NULL;\n"
+"		\n"
+"	while( ( rc = ap_regexec( regexp, src, regexp->re_nsub + 1, match, 0 ) ) == 0 ){\n"
+"		soffset = match[0].rm_so;\n"
+"		eoffset = match[0].rm_eo;\n"
+"		if( ( str = ap_pregsub( __p__, \"$1\", src, regexp->re_nsub + 1, match ) ) == NULL )\n"
+"			break;\n"
+"\n"
+"		result = apr_pstrcat( __p__, result,apr_pstrndup( __p__, src,soffset), replaceStr, NULL );\n"
+"		src +=eoffset;\n"
+"	}\n"
+"	result = apr_pstrcat( __p__, result,src, NULL);\n"
+"\n"
+"	ap_regfree(regexp);\n"
+"	return result;\n"
+"}\n"
+"\n"
+"\n"
+"///////////////////////////////////////////////////////////////////////\n"
 "//		table\n"
 "///////////////////////////////////////////////////////////////////////\n"
 "apr_table_t * tbl_make(int size){\n"
@@ -957,7 +1028,6 @@ static void sessionSet(int * session_index,struct _sessionTable * session,char *
 # 14 "include.c" 2
 
 
-
 ////////////////////////////////////////////////////////////////////////////////////////////////
 //		debug
 ////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1000,15 +1070,15 @@ static int csp_handler(request_rec *r)
     if (strcmp(r->handler, "csp")) {
         return DECLINED;
     }
-//    r->content_type = "text/html; charset=Shift_JIS";
-      r->content_type = "text/html";
+    r->content_type = "text/html";
 
     if (r->header_only)
 	    return OK;
 
+//	ap_rprintf(r,"filename = %s<br>\n",r->filename);
+//    return OK;
 
-//	apr_signal(SIGINT, my_signal_handler);
-	// Error buffer
+// 		Error buffer
 //    GROWMEM * errbuffer = getGrowMem(p,1024);
 
 	// make folder name by accessed file 
